@@ -12,8 +12,7 @@ class PDF::CMap
     # set [PDF 1.7 TABLE 5.17 Additional entries in a CMap dictionary]
     use PDF::COS::Tie;
     use PDF::COS::Name;
-    my subset Name-CMap of PDF::COS::Name where 'CMap';
-    has Name-CMap $.Type is entry(:required);
+    has PDF::COS::Name $.Type is entry(:required) where 'CMap';
     has PDF::COS::Name $.CMapName is entry(:required); #| (Required) The PostScript name of the CMap. It should be the same as the value of CMapName in the CMap file.
     has Hash $.CIDSystemInfo is entry(:required);         #| (Required) A dictionary containing entries that define the character collection for the CIDFont or CIDFonts associated with the CMap
     my subset ZeroOrOne of UInt where 0|1;
