@@ -29,34 +29,44 @@ class PDF::Catalog
     use PDF::NumberTree;
     has PDF::NumberTree $.PageLabels is entry;           #| (Optional; PDF 1.3) A number tree defining the page labeling for the document.
 
-    has PDF::COS::Dict $.Names is entry;                 #| (Optional; PDF 1.2) The document’s name dictionary
+    use PDF::NameTree;
+    my role Names does PDF::COS::Tie::Hash {
+        has PDF::NameTree $.Dests is entry;                  #| (Optional; PDF 1.2) A name tree mapping name strings to destinations.
+        has PDF::NameTree $.AP is entry;                     #| (Optional; PDF 1.3) A name tree mapping name strings to annotation appearance streams.
+        has PDF::NameTree $.JavaScript is entry;             #| (Optional; PDF 1.3) A name tree mapping name strings to document-level JavaScript actions.
+        has PDF::NameTree $.Pages is entry;                  #| (Optional; PDF 1.3) A name tree mapping name strings to visible pages for use in interactive forms.
+        has PDF::NameTree $.Templates is entry;              #| (Optional; PDF 1.3) A name tree mapping name strings to invisible (template) pages for use in interactive forms.
+        has PDF::NameTree $.IDS is entry;                    #| (Optional; PDF 1.3) A name tree mapping digital identifiers to Web Capture content sets.
+        has PDF::NameTree $.URLS is entry;                   #| (Optional; PDF 1.3) A name tree mapping uniform resource locators (URLs) to Web Capture content sets10.4, "Content Sets").
+        has PDF::NameTree $.EmbeddedFiles is entry;          #| (Optional; PDF 1.4) A name tree mapping name strings to file specifications for embedded file streams.
+        has PDF::NameTree $.AlternatePresentations is entry; #| (Optional; PDF 1.4) A name tree mapping name strings to alternate presentations.
+        has PDF::NameTree $.Renditions is entry;             #| (Optional; PDF 1.5) A name tree mapping name strings (which shall have Unicode encoding) to rendition objects.
+    }
+    has Names $.Names is entry;                  #| (Optional; PDF 1.2) The document’s name dictionary
 
-    has PDF::COS::Dict $.Dests is entry(:indirect);      #| (Optional; PDF 1.1; must be an indirect reference) A dictionary of names and corresponding destinations
+    use PDF::Destination :DestSpec, :coerce-dest;
+    has DestSpec %.Dests is entry(:coerce(&coerce-dest));    #| (Optional; PDF 1.1; must be an indirect reference) A dictionary of names and corresponding destinations
 
     use PDF::ViewerPreferences;
-    has PDF::ViewerPreferences $.ViewerPreferences is entry;  #| (Optional; PDF 1.2) A viewer preferences dictionary specifying the way the document is to be displayed on the screen.
+    has PDF::ViewerPreferences $.ViewerPreferences is entry; #| (Optional; PDF 1.2) A viewer preferences dictionary specifying the way the document is to be displayed on the screen.
 
     subset PageLayout of PDF::COS::Name where 'SinglePage'|'OneColumn'|'TwoColumnLeft'|'TwoColumnRight'|'TwoPageLeft'|'TwoPageRight';
-    has PageLayout $.PageLayout is entry;                     #| (Optional) A name object specifying the page layout to be used when the document is opened
+    has PageLayout $.PageLayout is entry;                    #| (Optional) A name object specifying the page layout to be used when the document is opened
 
     subset PageMode of PDF::COS::Name where 'UseNone'|'UseOutlines'|'UseThumbs'|'FullScreen'|'UseOC'|'UseAttachments';
-    has PageMode $.PageMode is entry;                         #| (Optional) A name object specifying how the document should be displayed when opened
+    has PageMode $.PageMode is entry;                        #| (Optional) A name object specifying how the document should be displayed when opened
 
     use PDF::Outlines;
     has PDF::Outlines $.Outlines is entry(:indirect); #| (Optional; must be an indirect reference) The outline dictionary that is the root of the document’s outline hierarchy
 
-    has PDF::COS::Dict @.Threads is entry(:indirect);         #| (Optional; PDF 1.1; must be an indirect reference) An array of thread dictionaries representing the document’s article threads
+    has PDF::COS::Dict @.Threads is entry(:indirect);        #| (Optional; PDF 1.1; must be an indirect reference) An array of thread dictionaries representing the document’s article threads
 
     use PDF::Action;
-    use PDF::Destination;
-    my subset ActionOrDestination where PDF::Action|PDF::Destination;
-    multi sub coerce(Hash $_, ActionOrDestination) {
-        PDF::COS.coerce( $_, PDF::Action.delegate-action($_) );
+    my subset ActionOrDestSpec where PDF::Action|DestSpec;
+    multi sub coerce(List $_ is rw, ActionOrDestSpec) is default {
+        coerce-dest($_, DestSpec);
     }
-    multi sub coerce(Array $_, ActionOrDestination) {
-        PDF::COS.coerce( $_, PDF::Destination.delegate-destination($_) );
-    }
-    has ActionOrDestination $.OpenAction is entry(:&coerce);               #| (Optional; PDF 1.1) A value specifying a destination to be displayed or an action to be performed when the document is opened.
+    has ActionOrDestSpec $.OpenAction is entry(:&coerce);    #| (Optional; PDF 1.1) A value specifying a destination to be displayed or an action to be performed when the document is opened.
 
     has PDF::COS::Dict $.AA is entry(:alias<additional-actions>);                    #| (Optional; PDF 1.4) An additional-actions dictionary defining the actions to be taken in response to various trigger events affecting the document as a whole
 
@@ -88,10 +98,12 @@ class PDF::Catalog
     has PDF::COS::Dict $.SpiderInfo is entry;            #| (Optional; PDF 1.3) A Web Capture information dictionary containing state information used by the Acrobat Web Capture (AcroSpider) plug-in extension
 
     use PDF::OutputIntent;
-    has PDF::OutputIntent @.OutputIntents is entry;         #| (Optional; PDF 1.4) An array of output intent dictionaries describing the color characteristics of output devices on which the document might be rendered
+    has PDF::OutputIntent @.OutputIntents is entry;      #| (Optional; PDF 1.4) An array of output intent dictionaries describing the color characteristics of output devices on which the document might be rendered
 
     has PDF::COS::Dict $.PieceInfo is entry;             #| (Optional; PDF 1.4) A page-piece dictionary associated with the document
 
+    my subset OCG of PDF::Class::Type where { .type eq 'OCG' }; # autoloaded PDF::OCG (Optional Content Group)
+
     role OCConfig
 	does PDF::COS::Tie::Hash {
         #| Table Table 101 – Entries in an Optional Content Configuration Dictionary
@@ -99,13 +111,13 @@ class PDF::Catalog
         has PDF::COS::TextString $.Creator is entry; #| (Optional) Name of the application or feature that created thisconfiguration dictionary.
         my subset BaseState of PDF::COS::Name where 'ON'|'OFF'|'Unchanged';
         has BaseState $.BaseState is entry; #| (Optional) Used to initialize the states of all the optional content groups in a document when this configuration is applied. The value of this entry shall be one of the following names:
-        has @.ON is entry;  #| (Optional) An array of optional content groups whose state shall be set to ON when this configuration is applied. If the BaseState entry is ON, this entry is redundant.
-        has @.OFF is entry; #| (Optional) An array of optional content groups whose state shall be set to OFF when this configuration is applied. If the BaseState entry is OFF, this entry is redundant.
-        has $.Intent is entry; #| name or array (Optional) A single intent name or an array containing any combination of names.
+        has OCG @.ON is entry;  #| (Optional) An array of optional content groups whose state shall be set to ON when this configuration is applied. If the BaseState entry is ON, this entry is redundant.
+        has OCG @.OFF is entry; #| (Optional) An array of optional content groups whose state shall be set to OFF when this configuration is applied. If the BaseState entry is OFF, this entry is redundant.
+        has PDF::COS::Name @.Intent is entry(:array-or-item); #| name or array (Optional) A single intent name or an array containing any combination of names.
         has @.AS is entry; #| (Optional) An array of usage application dictionaries.
         has @.Order is entry; #| array (Optional) An array specifying the order for presentation of optional content groups in a conforming reader’s user interface.
         my subset ListMode of PDF::COS::Name where 'AllPages'|'VisiblePages';
-        has PDF::COS::Name $.ListMode is entry; #| (Optional) A name specifying which optional content groups in the Order array shall be displayed to the user.
+        has ListMode $.ListMode is entry; #| (Optional) A name specifying which optional content groups in the Order array shall be displayed to the user.
         has @.RBGroups is entry; #| (Optional) An array consisting of one or more arrays, each of which represents a collection of optional content groups whose states shall be intended to follow a radio button paradigm. That is, the state of at most one optional content group in each array shall be ON at a time. If one group is turned ON, all others shall be turned OFF.
        has @.Locked is entry; #| (Optional; PDF 1.6) An array of optional content groups that shall be locked when this configuration is applied.
 }
@@ -113,21 +125,21 @@ class PDF::Catalog
     role OCProperties
 	does PDF::COS::Tie::Hash {
         #| Table 100 – Entries in the Optional Content Properties Dictionary
-        has @.OCGs is entry(:indirect, :required, :alias<optional-content-groups>); #| (Required) An array of indirect references to all the optional content groups in the document (see 8.11.2, "Optional Content Groups"), in any order. Every optional content group shall be included in this array
+        has OCG @.OCGs is entry(:indirect, :required, :alias<optional-content-groups>); #| (Required) An array of indirect references to all the optional content groups in the document (see 8.11.2, "Optional Content Groups"), in any order. Every optional content group shall be included in this array
         has PDF::COS::Dict $.D is entry(:required, :alias<viewing-config>); #| (Required) The default viewing optional content configuration dictionary (see 8.11.4.3, "Optional Content Configuration Dictionaries").
         has OCConfig @.Configs is entry;    #| (Optional) An array of alternate optional content configuration dictionaries (see 8.11.4.3, "Optional Content Configuration Dictionaries").
     }
-    has OCProperties $.OCProperties is entry;          #| (Optional; PDF 1.5; required if a document contains optional content) The document’s optional content properties dictionary
+    has OCProperties $.OCProperties is entry;   #| (Optional; PDF 1.5; required if a document contains optional content) The document’s optional content properties dictionary
 
-    has PDF::COS::Dict $.Perms is entry;                 #| (Optional; PDF 1.5) A permissions dictionary that specifies user access permissions for the document.
+    has PDF::COS::Dict $.Perms is entry;        #| (Optional; PDF 1.5) A permissions dictionary that specifies user access permissions for the document.
 
-    has PDF::COS::Dict $.Legal is entry;                 #| (Optional; PDF 1.5) A dictionary containing attestations regarding the content of a PDF document, as it relates to the legality of digital signatures
+    has PDF::COS::Dict $.Legal is entry;        #| (Optional; PDF 1.5) A dictionary containing attestations regarding the content of a PDF document, as it relates to the legality of digital signatures
 
-    has PDF::COS::Dict @.Requirements is entry;          #| (Optional; PDF 1.7) An array of requirement dictionaries representing requirements for the document.
+    has PDF::COS::Dict @.Requirements is entry; #| (Optional; PDF 1.7) An array of requirement dictionaries representing requirements for the document.
 
-    has PDF::COS::Dict $.Collection is entry;            #| (Optional; PDF 1.7) A collection dictionary that a PDF consumer uses to enhance the presentation of file attachments stored in the PDF document.
+    has PDF::COS::Dict $.Collection is entry;   #| (Optional; PDF 1.7) A collection dictionary that a PDF consumer uses to enhance the presentation of file attachments stored in the PDF document.
 
-    has Bool $.NeedsRendering is entry;        #| (Optional; PDF 1.7) A flag used to expedite the display of PDF documents containing XFA forms. It specifies whether the document must be regenerated when the document is first opened.
+    has Bool $.NeedsRendering is entry;         #| (Optional; PDF 1.7) A flag used to expedite the display of PDF documents containing XFA forms. It specifies whether the document must be regenerated when the document is first opened.
 
     use PDF::Resources;
     has PDF::Resources $.Resources is entry;
@@ -146,7 +158,8 @@ class PDF::Catalog
     }
 
     method cb-finish {
-        self<Pages>.cb-finish;
+        .is-indirect ||= True with self<Dests>;
+        self<Pages>.?cb-finish;
     }
 }
 
