@@ -72,7 +72,7 @@ PDF::COS.loader = class PDF::Class::Loader
         my $type = from-ast($dict<Type>);
         my $subtype = from-ast($dict<Subtype> // $dict<S>);
         $type ~~
-            'Border'|'Encoding' # classess with optional /type & unhandled subtype
+            'Border'|'Encoding'|'StructElem' # classess with optional /type & unhandled subtype
             |'Ind'|'Ttl'|'Org'  # handled by PDF::OCG User attribute
             ?? $base-class
             !! $.find-delegate( $type, $subtype, :$base-class );
@@ -112,6 +112,7 @@ PDF::COS.loader = class PDF::Class::Loader
 	my $type = do given $subtype {
             when 'Alpha'|'Luminosity' { 'Mask' }
             when 'GTS_PDFX' { 'OutputIntent' }
+            when 'GoTo'|'GoToE'|'Launch'|'Thread'|'URI'|'Sound'|'Movie'|'Hide'|'Named'|'SubmitForm'|'ResetForm'|'ImportData'|'JavaScript'|'SetOCGState'|'Rendition'|'Trans'|'GoTo3DView' { 'Action' }
             default { Nil }
 	};
 
