@@ -3,6 +3,6 @@ use PDF::Font;
 use PDF::Font::CIDFont;
 
 class PDF::Font::CIDFontType0
-    is PDF::Font::CIDFont
-    is PDF::Font {
+    is PDF::Font
+    does PDF::Font::CIDFont {
 }
