@@ -3,6 +3,7 @@ use PDF::Font;
 use PDF::Font::CIDFont;
 
 class PDF::Font::CIDFontType2
-    is PDF::Font::CIDFont
-    is PDF::Font {
+    is PDF::Font
+    does PDF::Font::CIDFont {
+
 }
