@@ -15,10 +15,9 @@ class PDF::Pages
 
     use PDF::COS::Tie;
     use PDF::COS::Name;
-    my subset Name-Pages of PDF::COS::Name where 'Pages';
 
     # see [PDF 1.7 TABLE 3.26 Required entries in a page tree node]
-    has Name-Pages $.Type is entry(:required);
+    has PDF::COS::Name $.Type is entry(:required) where 'Pages';
     has Hash $.Parent is entry(:indirect); #| (Required except in root node; must be an indirect reference) The page tree node that is the immediate parent of this one.
     has PDF::Content::PageNode @.Kids is entry(:required, :indirect);  #| (Required) An array of indirect references to the immediate children of this node. The children may be page objects or other page tree nodes.
     has UInt $.Count is entry(:required);   #| (Required) The number of leaf nodes (page objects) that are descendants of this node within the page tree.
