@@ -1,36 +1,36 @@
 use v6;
 
-use PDF::DAO::Dict;
+use PDF::COS::Tie::Hash;
 
 #| /ShadingType 1..7 - the Shading dictionary delegates
 
-class PDF::Shading
-    is PDF::DAO::Dict {
+role PDF::Shading
+    does PDF::COS::Tie::Hash {
 
-    use PDF::DAO::Tie;
-    use PDF::DAO::Array;
-    use PDF::DAO::Name;
-    subset ShadingTypeInt of Int where 1..7;
+    use PDF::COS::Tie;
+    use PDF::COS::Array;
+    use PDF::COS::Name;
+    my subset ShadingTypeInt of Int where 1..7;
     has ShadingTypeInt $.ShadingType is entry(:required);
 
     # see [PDF 1.7 TABLE 4.28 Entries common to all shading dictionaries]
     use PDF::ColorSpace;
-    my subset NameOrColorSpace of PDF::DAO where PDF::DAO::Name | PDF::ColorSpace;
+    my subset NameOrColorSpace of PDF::COS where PDF::COS::Name | PDF::ColorSpace;
     has NameOrColorSpace $.ColorSpace is entry(:required); #| (Required) The color space in which color values are expressed.
     has @.Background is entry;                        #| (Optional) An array of color components appropriate to the color space, specifying a single background color value.
     has Numeric @.BBox is entry(:len(4));             #| (Optional) An array of four numbers giving the left, bottom, right, and top coordinates, respectively, of the shading’s bounding box
     has Bool $.AntiAlias is entry;                    #| (Optional) A flag indicating whether to filter the shading function to prevent aliasing artifacts.
 
     # from PDF Spec 1.7 table 4.28
-    constant ShadingTypes = <Function Axial Radial FreeForm Lattice Coons Tensor>;
-    constant ShadingNames = %( ShadingTypes.pairs.invert );
+    my constant ShadingTypes = <Function Axial Radial FreeForm Lattice Coons Tensor>;
+    my constant ShadingNames = %( ShadingTypes.pairs.invert );
     method type {'Shading'}
     method subtype { ShadingTypes[ $.ShadingType - 1] }
 
     #| see also PDF::Class::Loader
     method delegate-shading(Hash :$dict!) {
 
-	use PDF::DAO::Util :from-ast;
+	use PDF::COS::Util :from-ast;
 	my UInt $type-int = from-ast $dict<ShadingType>;
 
 	unless $type-int ~~ ShadingTypeInt {
@@ -39,7 +39,7 @@ class PDF::Shading
 	}
 
 	my $subtype = ShadingTypes[$type-int - 1];
-	PDF::DAO.loader.find-delegate( 'Shading', $subtype );
+	PDF::COS.loader.find-delegate( 'Shading', $subtype );
     }
 
     method cb-init {
